@@ -35,7 +35,7 @@ fn to_buffer(
 fn read_batch(buffer: &[u8], size: usize, column: usize) -> Result<()> {
     let file = Cursor::new(buffer);
 
-    let reader = read::RecordReader::try_new(file, Some(vec![column]), None, None, None)?;
+    let reader = read::FileReader::try_new(file, Some(&[column]), None, None, None)?;
 
     for maybe_chunk in reader {
         let columns = maybe_chunk?;
@@ -57,6 +57,9 @@ fn add_benchmark(c: &mut Criterion) {
         let a = format!("read utf8 large 2^{}", i);
         c.bench_function(&a, |b| b.iter(|| read_batch(&buffer, size, 6).unwrap()));
 
+        let a = format!("read utf8 emoji 2^{}", i);
+        c.bench_function(&a, |b| b.iter(|| read_batch(&buffer, size, 12).unwrap()));
+
         let a = format!("read bool 2^{}", i);
         c.bench_function(&a, |b| b.iter(|| read_batch(&buffer, size, 3).unwrap()));
 
