@@ -7,24 +7,27 @@ use crate::error::Result;
 
 /// Trait describing how a struct presents itself to the
 /// [C data interface](https://arrow.apache.org/docs/format/CDataInterface.html) (FFI).
-/// Safety:
+/// # Safety
 /// Implementing this trait incorrect will lead to UB
-pub unsafe trait ToFfi {
+pub(crate) unsafe trait ToFfi {
     /// The pointers to the buffers.
     fn buffers(&self) -> Vec<Option<std::ptr::NonNull<u8>>>;
 
-    /// The offset
-    fn offset(&self) -> usize;
-
     /// The children
     fn children(&self) -> Vec<Arc<dyn Array>> {
         vec![]
     }
+
+    /// The offset
+    fn offset(&self) -> Option<usize>;
+
+    /// return a partial clone of self with an offset.
+    fn to_ffi_aligned(&self) -> Self;
 }
 
 /// Trait describing how a struct imports into itself from the
 /// [C data interface](https://arrow.apache.org/docs/format/CDataInterface.html) (FFI).
-pub trait FromFfi<T: ffi::ArrowArrayRef>: Sized {
+pub(crate) trait FromFfi<T: ffi::ArrowArrayRef>: Sized {
     /// Convert itself from FFI.
     /// # Safety
     /// This function is intrinsically `unsafe` as it requires the FFI to be made according
@@ -35,17 +38,23 @@ pub trait FromFfi<T: ffi::ArrowArrayRef>: Sized {
 macro_rules! ffi_dyn {
     ($array:expr, $ty:ty) => {{
         let array = $array.as_any().downcast_ref::<$ty>().unwrap();
-        (array.buffers(), array.children(), None)
+        (
+            array.offset().unwrap(),
+            array.buffers(),
+            array.children(),
+            None,
+        )
     }};
 }
 
 type BuffersChildren = (
+    usize,
     Vec<Option<std::ptr::NonNull<u8>>>,
     Vec<Arc<dyn Array>>,
     Option<Arc<dyn Array>>,
 );
 
-pub fn buffers_children_dictionary(array: &dyn Array) -> BuffersChildren {
+pub fn offset_buffers_children_dictionary(array: &dyn Array) -> BuffersChildren {
     use PhysicalType::*;
     match array.data_type().to_physical_type() {
         Null => ffi_dyn!(array, NullArray),
@@ -65,9 +74,10 @@ pub fn buffers_children_dictionary(array: &dyn Array) -> BuffersChildren {
         Union => ffi_dyn!(array, UnionArray),
         Map => ffi_dyn!(array, MapArray),
         Dictionary(key_type) => {
-            with_match_physical_dictionary_key_type!(key_type, |$T| {
+            match_integer_type!(key_type, |$T| {
                 let array = array.as_any().downcast_ref::<DictionaryArray<$T>>().unwrap();
                 (
+                    array.offset().unwrap(),
                     array.buffers(),
                     array.children(),
                     Some(array.values().clone()),
