@@ -2,7 +2,8 @@ use crate::{bitmap::Bitmap, datatypes::DataType};
 
 use crate::{
     array::{Array, FromFfi, ToFfi},
-    error::Result,
+    datatypes::PhysicalType,
+    error::ArrowError,
     ffi,
 };
 
@@ -14,21 +15,45 @@ pub struct NullArray {
 }
 
 impl NullArray {
+    /// Returns a new [`NullArray`].
+    /// # Errors
+    /// This function errors iff:
+    /// * The `data_type`'s [`crate::datatypes::PhysicalType`] is not equal to [`crate::datatypes::PhysicalType::Null`].
+    pub fn try_new(data_type: DataType, length: usize) -> Result<Self, ArrowError> {
+        if data_type.to_physical_type() != PhysicalType::Null {
+            return Err(ArrowError::oos(
+                "BooleanArray can only be initialized with a DataType whose physical type is Boolean",
+            ));
+        }
+
+        Ok(Self { data_type, length })
+    }
+
+    /// Returns a new [`NullArray`].
+    /// # Panics
+    /// This function errors iff:
+    /// * The `data_type`'s [`crate::datatypes::PhysicalType`] is not equal to [`crate::datatypes::PhysicalType::Null`].
+    pub fn new(data_type: DataType, length: usize) -> Self {
+        Self::try_new(data_type, length).unwrap()
+    }
+
+    /// Alias for `new`
+    pub fn from_data(data_type: DataType, length: usize) -> Self {
+        Self::new(data_type, length)
+    }
+
     /// Returns a new empty [`NullArray`].
     pub fn new_empty(data_type: DataType) -> Self {
-        Self::from_data(data_type, 0)
+        Self::new(data_type, 0)
     }
 
     /// Returns a new [`NullArray`].
     pub fn new_null(data_type: DataType, length: usize) -> Self {
-        Self::from_data(data_type, length)
-    }
-
-    /// Returns a new [`NullArray`].
-    pub fn from_data(data_type: DataType, length: usize) -> Self {
-        Self { data_type, length }
+        Self::new(data_type, length)
     }
+}
 
+impl NullArray {
     /// Returns a slice of the [`NullArray`].
     pub fn slice(&self, _offset: usize, length: usize) -> Self {
         Self {
@@ -66,9 +91,11 @@ impl Array for NullArray {
     fn slice(&self, offset: usize, length: usize) -> Box<dyn Array> {
         Box::new(self.slice(offset, length))
     }
+
     unsafe fn slice_unchecked(&self, offset: usize, length: usize) -> Box<dyn Array> {
         Box::new(self.slice(offset, length))
     }
+
     fn with_validity(&self, _: Option<Bitmap>) -> Box<dyn Array> {
         panic!("cannot set validity of a null array")
     }
@@ -95,8 +122,8 @@ unsafe impl ToFfi for NullArray {
 }
 
 impl<A: ffi::ArrowArrayRef> FromFfi<A> for NullArray {
-    unsafe fn try_from_ffi(array: A) -> Result<Self> {
-        let data_type = array.field().data_type().clone();
-        Ok(Self::from_data(data_type, array.array().len()))
+    unsafe fn try_from_ffi(array: A) -> Result<Self, ArrowError> {
+        let data_type = array.data_type().clone();
+        Self::try_new(data_type, array.array().len())
     }
 }
