@@ -28,7 +28,7 @@ impl<T: NativeType> From<MutablePrimitiveArray<T>> for PrimitiveArray<T> {
             None
         };
 
-        PrimitiveArray::<T>::from_data(other.data_type, other.values.into(), validity)
+        PrimitiveArray::<T>::new(other.data_type, other.values.into(), validity)
     }
 }
 
@@ -285,7 +285,19 @@ impl<T: NativeType> MutablePrimitiveArray<T> {
     /// # Panic
     /// Panics iff index is larger than `self.len()`.
     pub fn set(&mut self, index: usize, value: Option<T>) {
-        self.values[index] = value.unwrap_or_default();
+        assert!(index < self.len());
+        // Safety:
+        // we just checked bounds
+        unsafe { self.set_unchecked(index, value) }
+    }
+
+    /// Sets position `index` to `value`.
+    /// Note that if it is the first time a null appears in this array,
+    /// this initializes the validity bitmap (`O(N)`).
+    /// # Safety
+    /// Caller must ensure `index < self.len()`
+    pub unsafe fn set_unchecked(&mut self, index: usize, value: Option<T>) {
+        *self.values.get_unchecked_mut(index) = value.unwrap_or_default();
 
         if value.is_none() && self.validity.is_none() {
             // When the validity is None, all elements so far are valid. When one of the elements is set fo null,
@@ -295,7 +307,7 @@ impl<T: NativeType> MutablePrimitiveArray<T> {
             self.validity = Some(validity);
         }
         if let Some(x) = self.validity.as_mut() {
-            x.set(index, value.is_some())
+            x.set_unchecked(index, value.is_some())
         }
     }
 
@@ -352,7 +364,7 @@ impl<T: NativeType> MutableArray for MutablePrimitiveArray<T> {
     }
 
     fn as_box(&mut self) -> Box<dyn Array> {
-        Box::new(PrimitiveArray::from_data(
+        Box::new(PrimitiveArray::new(
             self.data_type.clone(),
             std::mem::take(&mut self.values).into(),
             std::mem::take(&mut self.validity).map(|x| x.into()),
@@ -360,7 +372,7 @@ impl<T: NativeType> MutableArray for MutablePrimitiveArray<T> {
     }
 
     fn as_arc(&mut self) -> Arc<dyn Array> {
-        Arc::new(PrimitiveArray::from_data(
+        Arc::new(PrimitiveArray::new(
             self.data_type.clone(),
             std::mem::take(&mut self.values).into(),
             std::mem::take(&mut self.validity).map(|x| x.into()),
