@@ -1,7 +1,7 @@
 use std::hint::unreachable_unchecked;
 use std::iter::FromIterator;
 
-use crate::bitmap::utils::merge_reversed;
+use crate::bitmap::utils::{merge_reversed, set_bit_unchecked};
 use crate::trusted_len::TrustedLen;
 
 use super::utils::{count_zeros, fmt, get_bit, set, set_bit, BitmapIter};
@@ -58,7 +58,7 @@ impl MutableBitmap {
         }
     }
 
-    /// Initializes an a pre-allocated [`MutableBitmap`] with capacity for `capacity` bits.
+    /// Initializes a pre-allocated [`MutableBitmap`] with capacity for `capacity` bits.
     #[inline]
     pub fn with_capacity(capacity: usize) -> Self {
         Self {
@@ -67,7 +67,7 @@ impl MutableBitmap {
         }
     }
 
-    /// Initializes an a pre-allocated [`MutableBitmap`] with capacity for `capacity` bits.
+    /// Reserves `additional` bits in the [`MutableBitmap`], potentially re-allocating its buffer.
     #[inline(always)]
     pub fn reserve(&mut self, additional: usize) {
         self.buffer
@@ -209,6 +209,14 @@ impl MutableBitmap {
         set_bit(self.buffer.as_mut_slice(), index, value)
     }
 
+    /// Sets the position `index` to `value`
+    /// # Safety
+    /// Caller must ensure that `index < self.len()`
+    #[inline]
+    pub unsafe fn set_unchecked(&mut self, index: usize, value: bool) {
+        set_bit_unchecked(self.buffer.as_mut_slice(), index, value)
+    }
+
     /// Shrinks the capacity of the [`MutableBitmap`] to fit its current length.
     pub fn shrink_to_fit(&mut self) {
         self.buffer.shrink_to_fit();
