@@ -4,20 +4,20 @@ use std::ops::Mul;
 use num_traits::{ops::overflowing::OverflowingMul, CheckedMul, SaturatingMul, WrappingMul};
 
 use crate::{
-    array::{Array, PrimitiveArray},
+    array::PrimitiveArray,
     bitmap::Bitmap,
     compute::{
         arithmetics::{
             ArrayCheckedMul, ArrayMul, ArrayOverflowingMul, ArraySaturatingMul, ArrayWrappingMul,
-            NativeArithmetics,
         },
         arity::{
             binary, binary_checked, binary_with_bitmap, unary, unary_checked, unary_with_bitmap,
         },
     },
-    types::NativeType,
 };
 
+use super::NativeArithmetics;
+
 /// Multiplies two primitive arrays with the same type.
 /// Panics if the multiplication of one pair of values overflows.
 ///
@@ -34,7 +34,7 @@ use crate::{
 /// ```
 pub fn mul<T>(lhs: &PrimitiveArray<T>, rhs: &PrimitiveArray<T>) -> PrimitiveArray<T>
 where
-    T: NativeType + Mul<Output = T>,
+    T: NativeArithmetics + Mul<Output = T>,
 {
     binary(lhs, rhs, lhs.data_type().clone(), |a, b| a * b)
 }
@@ -55,7 +55,7 @@ where
 /// ```
 pub fn wrapping_mul<T>(lhs: &PrimitiveArray<T>, rhs: &PrimitiveArray<T>) -> PrimitiveArray<T>
 where
-    T: NativeType + WrappingMul<Output = T>,
+    T: NativeArithmetics + WrappingMul<Output = T>,
 {
     let op = move |a: T, b: T| a.wrapping_mul(&b);
 
@@ -79,7 +79,7 @@ where
 /// ```
 pub fn checked_mul<T>(lhs: &PrimitiveArray<T>, rhs: &PrimitiveArray<T>) -> PrimitiveArray<T>
 where
-    T: NativeType + CheckedMul<Output = T>,
+    T: NativeArithmetics + CheckedMul<Output = T>,
 {
     let op = move |a: T, b: T| a.checked_mul(&b);
 
@@ -103,7 +103,7 @@ where
 /// ```
 pub fn saturating_mul<T>(lhs: &PrimitiveArray<T>, rhs: &PrimitiveArray<T>) -> PrimitiveArray<T>
 where
-    T: NativeType + SaturatingMul<Output = T>,
+    T: NativeArithmetics + SaturatingMul<Output = T>,
 {
     let op = move |a: T, b: T| a.saturating_mul(&b);
 
@@ -131,7 +131,7 @@ pub fn overflowing_mul<T>(
     rhs: &PrimitiveArray<T>,
 ) -> (PrimitiveArray<T>, Bitmap)
 where
-    T: NativeType + OverflowingMul<Output = T>,
+    T: NativeArithmetics + OverflowingMul<Output = T>,
 {
     let op = move |a: T, b: T| a.overflowing_mul(&b);
 
@@ -202,7 +202,7 @@ where
 /// ```
 pub fn mul_scalar<T>(lhs: &PrimitiveArray<T>, rhs: &T) -> PrimitiveArray<T>
 where
-    T: NativeType + Mul<Output = T>,
+    T: NativeArithmetics + Mul<Output = T>,
 {
     let rhs = *rhs;
     unary(lhs, |a| a * rhs, lhs.data_type().clone())
@@ -223,7 +223,7 @@ where
 /// ```
 pub fn wrapping_mul_scalar<T>(lhs: &PrimitiveArray<T>, rhs: &T) -> PrimitiveArray<T>
 where
-    T: NativeType + WrappingMul<Output = T>,
+    T: NativeArithmetics + WrappingMul<Output = T>,
 {
     unary(lhs, |a| a.wrapping_mul(rhs), lhs.data_type().clone())
 }
@@ -244,7 +244,7 @@ where
 /// ```
 pub fn checked_mul_scalar<T>(lhs: &PrimitiveArray<T>, rhs: &T) -> PrimitiveArray<T>
 where
-    T: NativeType + CheckedMul<Output = T>,
+    T: NativeArithmetics + CheckedMul<Output = T>,
 {
     let rhs = *rhs;
     let op = move |a: T| a.checked_mul(&rhs);
@@ -268,7 +268,7 @@ where
 /// ```
 pub fn saturating_mul_scalar<T>(lhs: &PrimitiveArray<T>, rhs: &T) -> PrimitiveArray<T>
 where
-    T: NativeType + SaturatingMul<Output = T>,
+    T: NativeArithmetics + SaturatingMul<Output = T>,
 {
     let rhs = *rhs;
     let op = move |a: T| a.saturating_mul(&rhs);
@@ -293,7 +293,7 @@ where
 /// ```
 pub fn overflowing_mul_scalar<T>(lhs: &PrimitiveArray<T>, rhs: &T) -> (PrimitiveArray<T>, Bitmap)
 where
-    T: NativeType + OverflowingMul<Output = T>,
+    T: NativeArithmetics + OverflowingMul<Output = T>,
 {
     let rhs = *rhs;
     let op = move |a: T| a.overflowing_mul(&rhs);
@@ -304,7 +304,7 @@ where
 // Implementation of ArrayMul trait for PrimitiveArrays with a scalar
 impl<T> ArrayMul<T> for PrimitiveArray<T>
 where
-    T: NativeType + Mul<Output = T> + NativeArithmetics,
+    T: NativeArithmetics + Mul<Output = T>,
 {
     fn mul(&self, rhs: &T) -> Self {
         mul_scalar(self, rhs)
