@@ -14,6 +14,7 @@ use super::schema::fb_to_schema;
 use super::Dictionaries;
 use arrow_format::ipc::planus::{ReadAsRoot, Vector};
 
+/// Metadata of an Arrow IPC file, written in the footer of the file.
 #[derive(Debug, Clone)]
 pub struct FileMetadata {
     /// The schema that is read from the file footer
@@ -25,10 +26,10 @@ pub struct FileMetadata {
     /// The blocks in the file
     ///
     /// A block indicates the regions in the file to read to get data
-    blocks: Vec<arrow_format::ipc::Block>,
+    pub(super) blocks: Vec<arrow_format::ipc::Block>,
 
     /// Dictionaries associated to each dict_id
-    dictionaries: Dictionaries,
+    pub(super) dictionaries: Dictionaries,
 }
 
 /// Arrow File reader
@@ -165,7 +166,7 @@ pub fn read_file_metadata<R: Read + Seek>(reader: &mut R) -> Result<FileMetadata
     })
 }
 
-fn get_serialized_batch<'a>(
+pub(super) fn get_serialized_batch<'a>(
     message: &'a arrow_format::ipc::MessageRef,
 ) -> Result<arrow_format::ipc::RecordBatchRef<'a>> {
     let header = message.header()?.ok_or_else(|| {
