@@ -1,15 +1,18 @@
+use chrono::{NaiveDate, NaiveDateTime};
 use lexical_core::ToLexical;
-use serde_json::Value;
+use std::io::Write;
 use streaming_iterator::StreamingIterator;
 
 use crate::bitmap::utils::zip_validity;
-use crate::chunk::Chunk;
+use crate::datatypes::TimeUnit;
 use crate::io::iterator::BufStreamingIterator;
+use crate::temporal_conversions::{
+    date32_to_date, date64_to_date, timestamp_ms_to_datetime, timestamp_ns_to_datetime,
+    timestamp_s_to_datetime, timestamp_us_to_datetime,
+};
 use crate::util::lexical_to_bytes_mut;
 use crate::{array::*, datatypes::DataType, types::NativeType};
 
-use super::{JsonArray, JsonFormat};
-
 fn boolean_serializer<'a>(
     array: &'a BooleanArray,
 ) -> Box<dyn StreamingIterator<Item = [u8]> + 'a + Send + Sync> {
@@ -47,7 +50,7 @@ fn utf8_serializer<'a, O: Offset>(
         array.iter(),
         |x, buf| {
             if let Some(x) = x {
-                utf8_serialize(x, buf)
+                serde_json::to_writer(buf, x).unwrap();
             } else {
                 buf.extend_from_slice(b"null")
             }
@@ -88,7 +91,7 @@ fn struct_serializer<'a>(
                         let item = iter.next().unwrap();
                         record.push((name, item));
                     });
-                serialize_item(buf, &record, JsonArray::default(), true);
+                serialize_item(buf, &record, true);
             } else {
                 serializers.iter_mut().for_each(|iter| {
                     let _ = iter.next();
@@ -137,21 +140,50 @@ fn list_serializer<'a, O: Offset>(
     ))
 }
 
-#[inline]
-fn utf8_serialize(value: &str, buf: &mut Vec<u8>) {
-    if value.as_bytes().is_ascii() {
-        buf.reserve(value.len() + 2);
-        buf.push(b'"');
-        buf.extend_from_slice(value.as_bytes());
-        buf.push(b'"');
-    } else {
-        // it may contain reserved keywords: perform roundtrip for
-        // todo: avoid this roundtrip over serde_json
-        serde_json::to_writer(buf, &Value::String(value.to_string())).unwrap();
-    }
+fn date_serializer<'a, T, F>(
+    array: &'a PrimitiveArray<T>,
+    convert: F,
+) -> Box<dyn StreamingIterator<Item = [u8]> + 'a + Send + Sync>
+where
+    T: NativeType,
+    F: Fn(T) -> NaiveDate + 'static + Send + Sync,
+{
+    Box::new(BufStreamingIterator::new(
+        array.iter(),
+        move |x, buf| {
+            if let Some(x) = x {
+                let nd = convert(*x);
+                write!(buf, "\"{}\"", nd).unwrap();
+            } else {
+                buf.extend_from_slice(b"null")
+            }
+        },
+        vec![],
+    ))
 }
 
-fn new_serializer<'a>(
+fn timestamp_serializer<'a, F>(
+    array: &'a PrimitiveArray<i64>,
+    convert: F,
+) -> Box<dyn StreamingIterator<Item = [u8]> + 'a + Send + Sync>
+where
+    F: Fn(i64) -> NaiveDateTime + 'static + Send + Sync,
+{
+    Box::new(BufStreamingIterator::new(
+        array.iter(),
+        move |x, buf| {
+            if let Some(x) = x {
+                let ndt = convert(*x);
+                write!(buf, "\"{}\"", ndt).unwrap();
+            } else {
+                buf.extend_from_slice(b"null")
+            }
+        },
+        vec![],
+    ))
+}
+
+pub(crate) fn new_serializer<'a>(
     array: &'a dyn Array,
 ) -> Box<dyn StreamingIterator<Item = [u8]> + 'a + Send + Sync> {
     match array.data_type().to_logical_type() {
@@ -171,17 +203,29 @@ fn new_serializer<'a>(
         DataType::Struct(_) => struct_serializer(array.as_any().downcast_ref().unwrap()),
         DataType::List(_) => list_serializer::<i32>(array.as_any().downcast_ref().unwrap()),
         DataType::LargeList(_) => list_serializer::<i64>(array.as_any().downcast_ref().unwrap()),
+        DataType::Date32 => date_serializer(array.as_any().downcast_ref().unwrap(), date32_to_date),
+        DataType::Date64 => date_serializer(array.as_any().downcast_ref().unwrap(), date64_to_date),
+        DataType::Timestamp(tu, tz) => {
+            if tz.is_some() {
+                todo!("still have to implement timezone")
+            } else {
+                let convert = match tu {
+                    TimeUnit::Nanosecond => timestamp_ns_to_datetime,
+                    TimeUnit::Microsecond => timestamp_us_to_datetime,
+                    TimeUnit::Millisecond => timestamp_ms_to_datetime,
+                    TimeUnit::Second => timestamp_s_to_datetime,
+                };
+                timestamp_serializer(array.as_any().downcast_ref().unwrap(), convert)
+            }
+        }
         other => todo!("Writing {:?} to JSON", other),
     }
 }
 
-fn serialize_item<F: JsonFormat>(
-    buffer: &mut Vec<u8>,
-    record: &[(&str, &[u8])],
-    format: F,
-    is_first_row: bool,
-) {
-    format.start_row(buffer, is_first_row).unwrap();
+fn serialize_item(buffer: &mut Vec<u8>, record: &[(&str, &[u8])], is_first_row: bool) {
+    if !is_first_row {
+        buffer.push(b',');
+    }
     buffer.push(b'{');
     let mut first_item = true;
     for (key, value) in record {
@@ -189,42 +233,23 @@ fn serialize_item<F: JsonFormat>(
             buffer.push(b',');
         }
         first_item = false;
-        utf8_serialize(key, buffer);
+        serde_json::to_writer(&mut *buffer, key).unwrap();
         buffer.push(b':');
         buffer.extend(*value);
     }
     buffer.push(b'}');
-    format.end_row(buffer).unwrap();
 }
 
-/// Serializes a (name, array) to a valid JSON to `buffer`
-/// This is CPU-bounded
-pub fn serialize<N, A, F>(names: &[N], columns: &Chunk<A>, format: F, buffer: &mut Vec<u8>)
-where
-    N: AsRef<str>,
-    A: AsRef<dyn Array>,
-    F: JsonFormat,
-{
-    let num_rows = columns.len();
+/// Serializes `array` to a valid JSON to `buffer`
+/// # Implementation
+/// This operation is CPU-bounded
+pub(crate) fn serialize(array: &dyn Array, buffer: &mut Vec<u8>) {
+    let mut serializer = new_serializer(array);
 
-    let mut serializers: Vec<_> = columns
-        .arrays()
-        .iter()
-        .map(|array| new_serializer(array.as_ref()))
-        .collect();
-
-    let mut is_first_row = true;
-    (0..num_rows).for_each(|_| {
-        let mut record: Vec<(&str, &[u8])> = Default::default();
-        serializers
-            .iter_mut()
-            .zip(names.iter())
-            // `unwrap` is infalible because `array.len()` equals `len` on `Chunk`
-            .for_each(|(iter, name)| {
-                let item = iter.next().unwrap();
-                record.push((name.as_ref(), item));
-            });
-        serialize_item(buffer, &record, format, is_first_row);
-        is_first_row = false;
-    })
+    (0..array.len()).for_each(|i| {
+        if i != 0 {
+            buffer.push(b',');
+        }
+        buffer.extend_from_slice(serializer.next().unwrap());
+    });
 }
