@@ -1,11 +1,9 @@
 use std::any::Any;
 use std::convert::{TryFrom, TryInto};
 
-use super::super::schema;
 use super::primitive::PrimitiveStatistics;
 use crate::datatypes::DataType;
 use crate::error::{ArrowError, Result};
-use parquet2::schema::types::ParquetType;
 use parquet2::{
     schema::types::PhysicalType,
     statistics::{
@@ -15,12 +13,18 @@ use parquet2::{
 
 use super::Statistics;
 
+/// Arrow-deserialized parquet Statistics of a fixed-len binary
 #[derive(Debug, Clone, PartialEq)]
 pub struct FixedLenStatistics {
+    /// number of nulls
     pub null_count: Option<i64>,
+    /// number of dictinct values
     pub distinct_count: Option<i64>,
+    /// Minimum
     pub min_value: Option<Vec<u8>>,
+    /// Maximum
     pub max_value: Option<Vec<u8>>,
+    /// data type
     pub data_type: DataType,
 }
 
@@ -96,10 +100,8 @@ impl TryFrom<(&ParquetFixedLenStatistics, DataType)> for PrimitiveStatistics<i12
 
 pub(super) fn statistics_from_fix_len(
     stats: &ParquetFixedLenStatistics,
-    type_: &ParquetType,
+    data_type: DataType,
 ) -> Result<Box<dyn Statistics>> {
-    let data_type = schema::to_data_type(type_)?.unwrap();
-
     use DataType::*;
     Ok(match data_type {
         Decimal(_, _) => Box::new(PrimitiveStatistics::<i128>::try_from((stats, data_type))?),
