@@ -1,11 +1,14 @@
 //! APIs exposing `parquet2`'s statistics as arrow's statistics.
-use crate::datatypes::DataType;
-use crate::error::ArrowError;
+use std::any::Any;
+
+use parquet2::metadata::ColumnChunkMetaData;
 use parquet2::schema::types::PhysicalType;
 use parquet2::statistics::PrimitiveStatistics as ParquetPrimitiveStatistics;
 use parquet2::statistics::Statistics as ParquetStatistics;
-use std::any::Any;
 
+use crate::datatypes::DataType;
+use crate::datatypes::Field;
+use crate::error::ArrowError;
 use crate::error::Result;
 
 mod primitive;
@@ -17,6 +20,8 @@ pub use boolean::*;
 mod fixlen;
 pub use fixlen::*;
 
+use super::get_field_columns;
+
 /// Trait representing a deserialized parquet statistics into arrow.
 pub trait Statistics: std::fmt::Debug {
     /// returns the [`DataType`] of the statistics.
@@ -41,19 +46,24 @@ impl PartialEq for Box<dyn Statistics> {
     }
 }
 
-pub fn deserialize_statistics(stats: &dyn ParquetStatistics) -> Result<Box<dyn Statistics>> {
+/// Deserializes [`ParquetStatistics`] into [`Statistics`] based on `data_type`.
+/// This takes into account the Arrow schema declared in Parquet's schema
+fn _deserialize_statistics(
+    stats: &dyn ParquetStatistics,
+    data_type: DataType,
+) -> Result<Box<dyn Statistics>> {
     match stats.physical_type() {
         PhysicalType::Int32 => {
             let stats = stats.as_any().downcast_ref().unwrap();
-            primitive::statistics_from_i32(stats, stats.descriptor.type_())
+            primitive::statistics_from_i32(stats, data_type)
         }
         PhysicalType::Int64 => {
             let stats = stats.as_any().downcast_ref().unwrap();
-            primitive::statistics_from_i64(stats, stats.descriptor.type_())
+            primitive::statistics_from_i64(stats, data_type)
         }
         PhysicalType::ByteArray => {
             let stats = stats.as_any().downcast_ref().unwrap();
-            binary::statistics_from_byte_array(stats, stats.descriptor.type_())
+            binary::statistics_from_byte_array(stats, data_type)
         }
         PhysicalType::Boolean => {
             let stats = stats.as_any().downcast_ref().unwrap();
@@ -65,8 +75,7 @@ pub fn deserialize_statistics(stats: &dyn ParquetStatistics) -> Result<Box<dyn S
                 .downcast_ref::<ParquetPrimitiveStatistics<f32>>()
                 .unwrap();
             Ok(Box::new(PrimitiveStatistics::<f32>::from((
-                stats,
-                DataType::Float32,
+                stats, data_type,
             ))))
         }
         PhysicalType::Double => {
@@ -75,16 +84,48 @@ pub fn deserialize_statistics(stats: &dyn ParquetStatistics) -> Result<Box<dyn S
                 .downcast_ref::<ParquetPrimitiveStatistics<f64>>()
                 .unwrap();
             Ok(Box::new(PrimitiveStatistics::<f64>::from((
-                stats,
-                DataType::Float64,
+                stats, data_type,
             ))))
         }
         PhysicalType::FixedLenByteArray(_) => {
             let stats = stats.as_any().downcast_ref().unwrap();
-            fixlen::statistics_from_fix_len(stats, stats.descriptor.type_())
+            fixlen::statistics_from_fix_len(stats, data_type)
         }
         _ => Err(ArrowError::NotYetImplemented(
             "Reading Fixed-len array statistics is not yet supported".to_string(),
         )),
     }
 }
+
+fn get_fields(field: &Field) -> Vec<&Field> {
+    match field.data_type.to_logical_type() {
+        DataType::List(inner) => get_fields(inner),
+        DataType::LargeList(inner) => get_fields(inner),
+        DataType::Struct(fields) => fields.iter().flat_map(get_fields).collect(),
+        _ => vec![field],
+    }
+}
+
+/// Deserializes [`ParquetStatistics`] into [`Statistics`] associated to `field`
+///
+/// For non-nested types, it returns a single column.
+/// For nested types, it returns one column per parquet primitive column.
+pub fn deserialize_statistics(
+    field: &Field,
+    columns: &[ColumnChunkMetaData],
+) -> Result<Vec<Option<Box<dyn Statistics>>>> {
+    let columns = get_field_columns(columns, field.name.as_ref());
+
+    let fields = get_fields(field);
+
+    columns
+        .into_iter()
+        .zip(fields.into_iter())
+        .map(|(column, field)| {
+            column
+                .statistics()
+                .map(|x| _deserialize_statistics(x?.as_ref(), field.data_type.clone()))
+                .transpose()
+        })
+        .collect()
+}
