@@ -3,7 +3,7 @@ use std::sync::Arc;
 use arrow2::chunk::Chunk;
 use avro_rs::types::{Record, Value};
 use avro_rs::{Codec, Writer};
-use avro_rs::{Days, Duration, Millis, Months, Schema as AvroSchema};
+use avro_rs::{Days, Decimal, Duration, Millis, Months, Schema as AvroSchema};
 
 use arrow2::array::*;
 use arrow2::datatypes::*;
@@ -36,11 +36,19 @@ pub(super) fn schema() -> (AvroSchema, Schema) {
                     "default": null
                 }
             }},
+            {"name": "i", "type": {
+                "type": "record",
+                "name": "bla",
+                "fields": [
+                    {"name": "e", "type": "double"}
+                ]
+            }},
             {"name": "enum", "type": {
                 "type": "enum",
                 "name": "",
                 "symbols" : ["SPADES", "HEARTS", "DIAMONDS", "CLUBS"]
-            }}
+            }},
+            {"name": "decimal", "type": {"type": "bytes", "logicalType": "decimal", "precision": 18, "scale": 5}}
         ]
     }
 "#;
@@ -59,11 +67,17 @@ pub(super) fn schema() -> (AvroSchema, Schema) {
             DataType::List(Box::new(Field::new("item", DataType::Int32, true))),
             false,
         ),
+        Field::new(
+            "i",
+            DataType::Struct(vec![Field::new("bla.e", DataType::Float64, false)]),
+            false,
+        ),
         Field::new(
             "enum",
             DataType::Dictionary(i32::KEY_TYPE, Box::new(DataType::Utf8), false),
             false,
         ),
+        Field::new("decimal", DataType::Decimal(18, 5), false),
     ]);
 
     (AvroSchema::parse_str(raw_schema).unwrap(), schema)
@@ -88,10 +102,19 @@ pub(super) fn data() -> Chunk<Arc<dyn Array>> {
         Arc::new(BooleanArray::from_slice([true, false])),
         Arc::new(Utf8Array::<i32>::from([Some("foo"), None])),
         array.into_arc(),
+        Arc::new(StructArray::from_data(
+            DataType::Struct(vec![Field::new("bla.e", DataType::Float64, false)]),
+            vec![Arc::new(PrimitiveArray::<f64>::from_slice([1.0, 2.0]))],
+            None,
+        )),
         Arc::new(DictionaryArray::<i32>::from_data(
             Int32Array::from_slice([1, 0]),
             Arc::new(Utf8Array::<i32>::from_slice(["SPADES", "HEARTS"])),
         )),
+        Arc::new(
+            PrimitiveArray::<i128>::from_slice([12345678i128, -12345678i128])
+                .to(DataType::Decimal(18, 5)),
+        ),
     ];
 
     Chunk::try_new(columns).unwrap()
@@ -120,7 +143,15 @@ pub(super) fn write_avro(codec: Codec) -> std::result::Result<Vec<u8>, avro_rs::
             Value::Union(Box::new(Value::Int(3))),
         ]),
     );
+    record.put(
+        "i",
+        Value::Record(vec![("e".to_string(), Value::Double(1.0f64))]),
+    );
     record.put("enum", Value::Enum(1, "HEARTS".to_string()));
+    record.put(
+        "decimal",
+        Value::Decimal(Decimal::from(&[0u8, 188u8, 97u8, 78u8])),
+    );
     record.put(
         "duration",
         Value::Duration(Duration::new(Months::new(1), Days::new(1), Millis::new(1))),
@@ -144,12 +175,25 @@ pub(super) fn write_avro(codec: Codec) -> std::result::Result<Vec<u8>, avro_rs::
             Value::Union(Box::new(Value::Int(3))),
         ]),
     );
+    record.put(
+        "i",
+        Value::Record(vec![("e".to_string(), Value::Double(2.0f64))]),
+    );
     record.put("enum", Value::Enum(0, "SPADES".to_string()));
+    record.put(
+        "decimal",
+        Value::Decimal(Decimal::from(&[
+            255u8, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 67, 158, 178,
+        ])),
+    );
     writer.append(record)?;
     Ok(writer.into_inner().unwrap())
 }
 
-pub(super) fn read_avro(mut avro: &[u8]) -> Result<(Chunk<Arc<dyn Array>>, Schema)> {
+pub(super) fn read_avro(
+    mut avro: &[u8],
+    projection: Option<Vec<bool>>,
+) -> Result<(Chunk<Arc<dyn Array>>, Schema)> {
     let file = &mut avro;
 
     let (avro_schema, schema, codec, file_marker) = read::read_metadata(file)?;
@@ -158,8 +202,21 @@ pub(super) fn read_avro(mut avro: &[u8]) -> Result<(Chunk<Arc<dyn Array>>, Schem
         read::Decompressor::new(read::BlockStreamIterator::new(file, file_marker), codec),
         avro_schema,
         schema.fields.clone(),
+        projection.clone(),
     );
 
+    let schema = if let Some(projection) = projection {
+        let fields = schema
+            .fields
+            .into_iter()
+            .zip(projection.iter())
+            .filter_map(|x| if *x.1 { Some(x.0) } else { None })
+            .collect::<Vec<_>>();
+        Schema::from(fields)
+    } else {
+        schema
+    };
+
     reader.next().unwrap().map(|x| (x, schema))
 }
 
@@ -168,7 +225,7 @@ fn test(codec: Codec) -> Result<()> {
     let expected = data();
     let (_, expected_schema) = schema();
 
-    let (result, schema) = read_avro(&avro)?;
+    let (result, schema) = read_avro(&avro, None)?;
 
     assert_eq!(schema, expected_schema);
     assert_eq!(result, expected);
@@ -189,3 +246,36 @@ fn read_deflate() -> Result<()> {
 fn read_snappy() -> Result<()> {
     test(Codec::Snappy)
 }
+
+fn test_projected(projection: Vec<bool>) -> Result<()> {
+    let avro = write_avro(Codec::Null).unwrap();
+    let expected = data();
+    let expected = expected
+        .into_arrays()
+        .into_iter()
+        .zip(projection.iter())
+        .filter_map(|x| if *x.1 { Some(x.0) } else { None })
+        .collect();
+    let expected = Chunk::new(expected);
+    let (_, expected_schema) = schema();
+    let expected_fields = expected_schema
+        .fields
+        .into_iter()
+        .zip(projection.iter())
+        .filter_map(|x| if *x.1 { Some(x.0) } else { None })
+        .collect::<Vec<_>>();
+    let expected_schema = Schema::from(expected_fields);
+
+    let (result, schema) = read_avro(&avro, Some(projection))?;
+
+    assert_eq!(schema, expected_schema);
+    assert_eq!(result, expected);
+    Ok(())
+}
+
+#[test]
+fn read_projected() -> Result<()> {
+    test_projected(vec![
+        true, false, false, false, false, false, false, false, false, false, false, false,
+    ])
+}
