@@ -13,12 +13,12 @@ fn test_file(version: &str, file_name: &str) -> Result<()> {
     ))?;
 
     // read expected JSON output
-    let (schema, batches) = read_gzip_json(version, file_name)?;
+    let (schema, _, batches) = read_gzip_json(version, file_name)?;
 
     let metadata = read_file_metadata(&mut file)?;
     let reader = FileReader::new(file, metadata, None);
 
-    assert_eq!(&schema, reader.schema().as_ref());
+    assert_eq!(&schema, reader.schema());
 
     batches.iter().zip(reader).try_for_each(|(lhs, rhs)| {
         assert_eq!(lhs, &rhs?);
@@ -146,11 +146,13 @@ fn read_generated_017_union() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(miri, ignore)] // LZ4 uses foreign calls that miri does not support
 fn read_generated_200_compression_lz4() -> Result<()> {
     test_file("2.0.0-compression", "generated_lz4")
 }
 
 #[test]
+#[cfg_attr(miri, ignore)] // ZSTD uses foreign calls that miri does not support
 fn read_generated_200_compression_zstd() -> Result<()> {
     test_file("2.0.0-compression", "generated_zstd")
 }
@@ -165,10 +167,10 @@ fn test_projection(version: &str, file_name: &str, column: usize) -> Result<()>
     let metadata = read_file_metadata(&mut file)?;
     let mut reader = FileReader::new(&mut file, metadata, Some(vec![column]));
 
-    assert_eq!(reader.schema().fields().len(), 1);
+    assert_eq!(reader.schema().fields.len(), 1);
 
     reader.try_for_each(|rhs| {
-        assert_eq!(rhs?.num_columns(), 1);
+        assert_eq!(rhs?.arrays().len(), 1);
         Result::Ok(())
     })?;
     Ok(())
